================================
Space Physics WebServices Client
================================


.. image:: https://img.shields.io/pypi/v/spwc.svg
        :target: https://pypi.python.org/pypi/spwc

.. image:: https://github.com/SciQLop/spwc/workflows/Python%20package/badge.svg
        :target: https://github.com/SciQLop/spwc/actions?query=workflow%3A%22Python+package%22

.. image:: https://readthedocs.org/projects/spwc/badge/?version=latest
        :target: https://spwc.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://codecov.io/gh/SciQLop/spwc/coverage.svg?branch=master
        :target: https://codecov.io/gh/SciQLop/spwc/branch/master
        :alt: Coverage Status

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.4118781.svg
   :target: https://doi.org/10.5281/zenodo.4118781
   :alt: Zendoo DOI

A simple Python package to deal with main Space Physics WebServices (CDA,CSA,AMDA,..) mainly written to ease development of SciQLop.


* Free software: GNU General Public License v3
* Documentation: https://spwc.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
